@@ -5,7 +5,7 @@ use warnings;
 use Config;
 use Carp qw(croak);
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # =============================================================================
 # Cache Directory Management
@@ -249,59 +249,120 @@ sub add_platform_detection {
 # Library Detection
 # =============================================================================
 
+# Check if a library can actually be linked (compile+link test)
+# This is the definitive test - if this fails, the JIT code won't load
+sub can_link {
+    my ($class, $cflags, $ldflags, $test_symbol, $extra_includes) = @_;
+    $cflags //= '';
+    $ldflags //= '';
+    $extra_includes //= '';
+
+    require File::Temp;
+
+    # Create minimal C code that references the symbol
+    # Use a void* cast to avoid prototype conflicts
+    my $test_code = <<"C";
+$extra_includes
+int main() {
+    void *p = (void*)$test_symbol;
+    return p ? 0 : 1;
+}
+C
+
+    # Write to temp file
+    my $src = File::Temp->new(SUFFIX => '.c', UNLINK => 1);
+    my $src_path = $src->filename;
+    print $src $test_code;
+    close $src;
+
+    # Output file
+    my $out = File::Temp->new(SUFFIX => '', UNLINK => 1);
+    my $out_path = $out->filename;
+    close $out;
+
+    # Try to compile and link
+    my $cc = $ENV{CC} || 'cc';
+    my $result = system("$cc $cflags -o $out_path $src_path $ldflags 2>/dev/null");
+
+    # Clean up output file
+    unlink $out_path if -f $out_path;
+
+    return $result == 0;
+}
+
 sub detect_library {
     my ($class, $lib_name, %opts) = @_;
-    
+
     my $result = {
         available => 0,
         cflags    => '',
         ldflags   => '',
     };
-    
+
+    my $test_symbol = $opts{test_symbol};
+    my $test_include = $opts{test_include} // '';
+
     # Try Alien module first
     my $alien_module = $opts{alien} // "Alien::\u$lib_name";
     if (eval "require $alien_module; 1") {
-        $result->{available} = 1;
-        $result->{cflags}  = $alien_module->cflags;
-        $result->{ldflags} = $alien_module->libs;
-        return $result;
+        my $cflags = $alien_module->cflags // '';
+        my $ldflags = $alien_module->libs // '';
+
+        # Verify it actually links if test_symbol provided
+        if (!$test_symbol || $class->can_link($cflags, $ldflags, $test_symbol, $test_include)) {
+            $result->{available} = 1;
+            $result->{cflags}  = $cflags;
+            $result->{ldflags} = $ldflags;
+            return $result;
+        }
     }
-    
+
     # Try pkg-config
     my $pkg_name = $opts{pkg_config} // $lib_name;
     my $cflags = `pkg-config --cflags $pkg_name 2>/dev/null`;
     my $ldflags = `pkg-config --libs $pkg_name 2>/dev/null`;
-    
+
     if ($? == 0 && $ldflags) {
         chomp($cflags);
         chomp($ldflags);
-        $result->{available} = 1;
-        $result->{cflags}  = $cflags;
-        $result->{ldflags} = $ldflags;
-        return $result;
+
+        # Verify it actually links if test_symbol provided
+        if (!$test_symbol || $class->can_link($cflags, $ldflags, $test_symbol, $test_include)) {
+            $result->{available} = 1;
+            $result->{cflags}  = $cflags;
+            $result->{ldflags} = $ldflags;
+            return $result;
+        }
     }
-    
-    # Try common paths
-    my @search_paths = $opts{paths} // qw(
-        /usr
-        /usr/local
-        /opt/homebrew
-        /opt/local
-    );
-    
+
+    # Try common paths (with additional Homebrew versioned paths for OpenSSL)
+    my @search_paths = @{$opts{paths} // [
+        # macOS Homebrew (Apple Silicon) - versioned first
+        '/opt/homebrew/opt/openssl@3',
+        '/opt/homebrew/opt/openssl',
+        '/opt/homebrew',
+        # macOS Homebrew (Intel) - versioned first
+        '/usr/local/opt/openssl@3',
+        '/usr/local/opt/openssl',
+        '/usr/local',
+        # Linux standard locations
+        '/usr',
+        '/opt/local',
+    ]};
+
     my $header = $opts{header};
     my $lib = $opts{lib} // "lib$lib_name";
-    
+
     for my $prefix (@search_paths) {
         my $inc_dir = "$prefix/include";
         my $lib_dir = "$prefix/lib";
-        
+
         # Check for header if specified
         if ($header && !-f "$inc_dir/$header") {
             next;
         }
-        
-        # Check for library
+
+        # Check for library file
         my $found_lib = 0;
         for my $ext (qw(.dylib .so .a)) {
             if (-f "$lib_dir/$lib$ext") {
@@ -309,44 +370,56 @@ sub detect_library {
                 last;
             }
         }
-        
+
         if ($found_lib) {
-            $result->{available} = 1;
-            $result->{cflags}  = "-I$inc_dir";
-            $result->{ldflags} = "-L$lib_dir -l$lib_name";
-            return $result;
+            my $try_cflags = "-I$inc_dir";
+            my $try_ldflags = "-L$lib_dir -l$lib_name";
+
+            # Verify it actually links if test_symbol provided
+            if (!$test_symbol || $class->can_link($try_cflags, $try_ldflags, $test_symbol, $test_include)) {
+                $result->{available} = 1;
+                $result->{cflags}  = $try_cflags;
+                $result->{ldflags} = $try_ldflags;
+                return $result;
+            }
         }
     }
-    
+
     return $result;
 }
 
 # Convenience methods for common libraries
 sub detect_openssl {
     my ($class) = @_;
-    return $class->detect_library('openssl', 
-        alien      => 'Alien::OpenSSL',
-        pkg_config => 'openssl',
-        header     => 'openssl/ssl.h',
-        lib        => 'libssl',
+    return $class->detect_library('ssl',
+        alien        => 'Alien::OpenSSL',
+        pkg_config   => 'openssl',
+        header       => 'openssl/ssl.h',
+        lib          => 'libssl',
+        test_symbol  => 'SSL_new',
+        test_include => '#include <openssl/ssl.h>',
     );
 }
 
 sub detect_zlib {
     my ($class) = @_;
     return $class->detect_library('z',
-        alien      => 'Alien::zlib',
-        pkg_config => 'zlib',
-        header     => 'zlib.h',
-        lib        => 'libz',
+        alien        => 'Alien::zlib',
+        pkg_config   => 'zlib',
+        header       => 'zlib.h',
+        lib          => 'libz',
+        test_symbol  => 'deflate',
+        test_include => '#include <zlib.h>',
     );
 }
 
 sub detect_nghttp2 {
     my ($class) = @_;
     return $class->detect_library('nghttp2',
-        pkg_config => 'libnghttp2',
-        header     => 'nghttp2/nghttp2.h',
+        pkg_config   => 'libnghttp2',
+        header       => 'nghttp2/nghttp2.h',
+        test_symbol  => 'nghttp2_session_client_new',
+        test_include => '#include <nghttp2/nghttp2.h>',
     );
 }
 
