@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # JIT-compiled TLS/HTTPS support for Hypersonic
 # Uses OpenSSL for TLS support (via Alien::OpenSSL when available)
@@ -16,56 +16,16 @@ use XS::JIT::Builder;
 my $COMPILED = 0;
 my $MODULE_ID = 0;
 
-# Cache for OpenSSL check result
-my $OPENSSL_AVAILABLE;
+# Cache for OpenSSL detection result
+my $OPENSSL_DETECTION;
 
-# Check if OpenSSL is available
+# Check if OpenSSL is available (uses centralized detection)
 sub check_openssl {
-    # Return cached result if already checked
-    return $OPENSSL_AVAILABLE if defined $OPENSSL_AVAILABLE;
+    return $OPENSSL_DETECTION->{available} if defined $OPENSSL_DETECTION;
 
-    # First try Alien::OpenSSL - this is the portable CPAN way
-    if (eval { require Alien::OpenSSL; 1 }) {
-        $OPENSSL_AVAILABLE = 1;
-        return 1;
-    }
-
-    # Quick check: do the header files exist?
-    my $cflags = get_extra_cflags();
-    if ($cflags =~ /-I(.+)/) {
-        my $inc_dir = $1;
-        # Check for openssl headers - they might be in $inc_dir or $inc_dir/openssl
-        if (-f "$inc_dir/ssl.h" || -f "$inc_dir/openssl/ssl.h") {
-            $OPENSSL_AVAILABLE = 1;
-            return 1;
-        }
-    }
-
-    # Fallback: try to compile a minimal test program
-    my $cc = $ENV{CC} || 'cc';
-    my $ldflags = get_extra_ldflags();
-
-    my $test_code = <<'C';
-#include <openssl/opensslv.h>
-int main() { return OPENSSL_VERSION_NUMBER > 0 ? 0 : 1; }
-C
-
-    my $tmp = "/tmp/hypersonic_ssl_check_$$.c";
-    my $out = "/tmp/hypersonic_ssl_check_$$";
-
-    if (open my $fh, '>', $tmp) {
-        print $fh $test_code;
-        close $fh;
-
-        my $result = system("$cc $cflags -o $out $tmp $ldflags 2>/dev/null");
-        unlink $tmp, $out;
-
-        $OPENSSL_AVAILABLE = ($result == 0) ? 1 : 0;
-        return $OPENSSL_AVAILABLE;
-    }
-
-    $OPENSSL_AVAILABLE = 0;
-    return 0;
+    require Hypersonic::JIT::Util;
+    $OPENSSL_DETECTION = Hypersonic::JIT::Util->detect_openssl();
+    return $OPENSSL_DETECTION->{available};
 }
 
 # Unified compile interface
@@ -595,80 +555,20 @@ sub generate_tls_code {
     );
 }
 
-# Cache for flags
-my ($CACHED_CFLAGS, $CACHED_LDFLAGS);
-
-# Get extra compiler flags for OpenSSL
+# Get extra compiler flags for OpenSSL (uses centralized detection)
 sub get_extra_cflags {
-    return $CACHED_CFLAGS if defined $CACHED_CFLAGS;
-
-    # Use Alien::OpenSSL if available (portable across all platforms)
-    if (eval { require Alien::OpenSSL; 1 }) {
-        $CACHED_CFLAGS = Alien::OpenSSL->cflags;
-        return $CACHED_CFLAGS;
-    }
-
-    # Fallback to common paths (ordered by likelihood)
-    my @search_paths = (
-        # macOS Homebrew (Apple Silicon)
-        '/opt/homebrew/opt/openssl@3/include',
-        '/opt/homebrew/opt/openssl/include',
-        # macOS Homebrew (Intel)
-        '/usr/local/opt/openssl@3/include',
-        '/usr/local/opt/openssl/include',
-        # Linux standard locations
-        '/usr/include',              # Most Linux distros (headers in /usr/include/openssl/)
-        '/usr/local/include',        # Manually installed
-        # FreeBSD
-        '/usr/local/include',
-    );
-
-    for my $path (@search_paths) {
-        # Check if openssl headers exist in this path
-        if (-f "$path/openssl/ssl.h") {
-            $CACHED_CFLAGS = "-I$path";
-            return $CACHED_CFLAGS;
-        }
-    }
-
-    $CACHED_CFLAGS = '';
-    return '';
+    require Hypersonic::JIT::Util;
+    $OPENSSL_DETECTION //= Hypersonic::JIT::Util->detect_openssl();
+    return $OPENSSL_DETECTION->{cflags} // '';
 }
 
 sub get_extra_ldflags {
-    return $CACHED_LDFLAGS if defined $CACHED_LDFLAGS;
-
-    # Use Alien::OpenSSL if available (portable across all platforms)
-    if (eval { require Alien::OpenSSL; 1 }) {
-        $CACHED_LDFLAGS = Alien::OpenSSL->libs;
-        return $CACHED_LDFLAGS;
-    }
-
-    # Fallback to common paths
-    my @search_paths = (
-        # macOS Homebrew (Apple Silicon)
-        '/opt/homebrew/opt/openssl@3/lib',
-        '/opt/homebrew/opt/openssl/lib',
-        # macOS Homebrew (Intel)
-        '/usr/local/opt/openssl@3/lib',
-        '/usr/local/opt/openssl/lib',
-        # Linux standard locations
-        '/usr/lib/x86_64-linux-gnu',  # Debian/Ubuntu
-        '/usr/lib64',                  # RHEL/CentOS/Fedora
-        '/usr/lib',                    # Generic
-        '/usr/local/lib',              # Manually installed
-    );
-
-    my @flags = ('-lssl', '-lcrypto');
-    for my $path (@search_paths) {
-        if (-f "$path/libssl.so" || -f "$path/libssl.dylib" || -f "$path/libssl.a") {
-            unshift @flags, "-L$path";
-            last;
-        }
-    }
-
-    $CACHED_LDFLAGS = join(' ', @flags);
-    return $CACHED_LDFLAGS;
+    require Hypersonic::JIT::Util;
+    $OPENSSL_DETECTION //= Hypersonic::JIT::Util->detect_openssl();
+    # Need both -lssl and -lcrypto for full OpenSSL
+    my $ldflags = $OPENSSL_DETECTION->{ldflags} // '';
+    $ldflags .= ' -lcrypto' unless $ldflags =~ /-lcrypto/;
+    return $ldflags;
 }
 
 1;
